@@ -541,34 +541,31 @@
 
 # InitHook - The InitHook function attaches initialization and destruction hooks to an object.
 
-    package MyClass;
-
-    use Extender;
+    package TestObject;
 
     sub new {
-        my $class = shift;
+        my $self = bless {}, shift;
+        return $self;
+    }
 
-        # Initialization $self
-        my $self = Extend({}, 'Extender');
-
-        # Initialization INIT hook
-        $self->InitHook('INIT', sub { print "Initializing object\n" });
-
-        # Destruction DESTRUCT hook
-        $self->InitHook('DESTRUCT', sub { print "Destructing object\n" });
-
-        return bless $self, $class
+    sub DESTROY {
+        my $self = shift;
+        # Implement destruction logic if needed
     }
 
     package main;
+    use Extender;
 
-    use MyClass;
+    InitHook('TestObject', 'INIT', sub {
+        print "Initializing object\n";
+    });
 
-    # Creating an instance triggers INIT hook
-    my $object = MyClass->new();  # Outputs: Initializing object
+    InitHook('TestObject', 'DESTRUCT', sub {
+        print "Destructing object\n";
+    });
 
-    # Destroying an instance triggers DESTRUCT hook
-    undef $object;  # Outputs: Destructing object
+    my $object = TestObject->new(); # Output: Initializing object
+    undef $object; # Output: Destructing object
 
     1;
 
