@@ -26,6 +26,8 @@ Extender - Dynamically enhance Perl objects with additional methods from other m
 
 =head1 SYNOPSIS
 
+    ############################################################################
+
     use Extender;
 
     # Example: Extend an object with methods from a module
@@ -41,6 +43,8 @@ Extender - Dynamically enhance Perl objects with additional methods from other m
     $object->greet('Alice');
     $object->custom_method();
 
+    ############################################################################
+
 =head1 DESCRIPTION
 
 Extender is a Perl module that facilitates the dynamic extension of objects with methods from other modules or custom-defined subroutines. It allows you to enhance Perl objects - whether hash references, array references, or scalar references - with additional functionalities without altering their original definitions.
@@ -73,6 +77,8 @@ This function extends the specified C<$object> by importing methods from the mod
 
 =head3 Example:
 
+    ############################################################################
+
     use Extender;
 
     # Create an object and extend $object with methods from 'Hash::Util'
@@ -80,6 +86,8 @@ This function extends the specified C<$object> by importing methods from the mod
 
     # Now $object has 'keys' and 'values' methods from 'Hash::Util'
 
+    ############################################################################
+
 =cut
 
 sub Extend {
@@ -124,6 +132,8 @@ This function extends the specified C<$object> by adding custom methods defined
 
 =head3 Example:
 
+    ############################################################################
+
     use Extender;
 
     # Create an object and define custom methods to extend $object
@@ -135,6 +145,8 @@ This function extends the specified C<$object> by adding custom methods defined
 
     # Now $object has 'custom_method' and 'dynamic_method'
 
+    ############################################################################
+
 =cut
 
 sub Extends {
@@ -183,6 +195,8 @@ This function creates an alias for an existing method in the object with a new n
 
 =head3 Example:
 
+    ############################################################################
+
     use Extender;
 
     my $object = Extends({}, original_method => sub {
@@ -195,6 +209,8 @@ This function creates an alias for an existing method in the object with a new n
     # Using the alias
     print $object->new_alias(), "\n";  # Outputs: Original method
 
+    ############################################################################
+
 =cut
 
 sub Alias {
@@ -244,6 +260,8 @@ This function adds a new method to the object's namespace. It validates the meth
 
 =head3 Example:
 
+    ############################################################################
+
     use Extender;
 
     my $object = Extends({}, custom_method => sub {
@@ -258,6 +276,8 @@ This function adds a new method to the object's namespace. It validates the meth
     my $result = $object->custom_method2('foo', 'bar');
     print "$result\n";  # Outputs: Custom method2 called with args: foo, bar
 
+    ############################################################################
+
 =cut
 
 sub AddMethod {
@@ -299,6 +319,8 @@ This function allows decorating an existing method of an object with a custom de
 
 =head3 Example:
 
+    ############################################################################
+
     use Extender;
 
     # Define a decorator function
@@ -323,6 +345,8 @@ This function allows decorating an existing method of an object with a custom de
     # Output the counter value
     print "Counter: ", $object->{counter}, "\n";
 
+    ############################################################################
+
 =cut
 
 sub Decorate {
@@ -387,6 +411,8 @@ This function loads a role class using C<require>, imports its methods into the
 
 =head3 Example
 
+    ############################################################################
+
     # Define a role (mixin)
     package MyRole;
     
@@ -401,7 +427,10 @@ This function loads a role class using C<require>, imports its methods into the
     sub foo { print "foo\n" }
     sub bar { print "bar\n" }
 
+    ############################################################################
+
     package main;
+
     use Extender;
 
     # Apply the role to an object
@@ -412,6 +441,8 @@ This function loads a role class using C<require>, imports its methods into the
     $object->foo();  # Outputs: foo
     $object->bar();  # Outputs: bar
 
+    ############################################################################
+
 =cut
 
 sub ApplyRole {
@@ -471,34 +502,39 @@ This function adds a code reference to the specified hook array (`_init_hooks` o
 
 =head3 Example:
 
+    ############################################################################
+
     package MyClass;
-    
-    use Extender;
-    
+
     sub new {
-        my ($class)=@_;
-        my $self=Extend({},'Extender');
-
-        # Add initialization hook
-        $self->InitHook('INIT', sub {
-            print "Object initialized\n";
-        });
-
-        # Add destruction hook
-        $self->InitHook('DESTRUCT', sub {
-            print "Object destroyed\n";
-        });
-
-        return bless $self, $class
+        my $self = bless {}, shift;
+        return $self;
     }
 
+    sub DESTROY {
+        my $self = shift;
+        # Implement destruction logic if needed
+    }
+
+    ############################################################################
+
     package main;
 
-    # Create an object
-    my $object = MyClass->new();
+    use Extender;
+    use MyClass;
 
-    # Destroy an object
-    undef $object;
+    InitHook('MyClass', 'INIT', sub {
+        print "Initializing object\n";
+    });
+
+    InitHook('MyClass', 'DESTRUCT', sub {
+        print "Destructing object\n";
+    });
+
+    my $object = MyClass->new(); # Output: Initializing object
+    undef $object; # Output: Destructing object
+
+    ############################################################################
 
 =cut
 
@@ -570,6 +606,8 @@ It effectively unloads or deletes methods that were previously added or defined
 
 =head3 Example:
 
+    ############################################################################
+
     use Extender;
 
     my $object = Extends({}, example_method => sub {
@@ -587,6 +625,8 @@ It effectively unloads or deletes methods that were previously added or defined
         print "Error: $@\n";
     }
 
+    ############################################################################
+
 =cut
 
 sub Unload {
@@ -628,6 +668,8 @@ sub Unload {
 
 =head2 Extend an Object with Methods from a Module
 
+    ############################################################################
+
     use Extender;
 
     # Extend an object with methods from a module
@@ -636,8 +678,12 @@ sub Unload {
     # Now $object can use any method from Some::Class
     $object->method1(1, 2, 3, 4);
 
+    ############################################################################
+
 =head2 Extend an Object with Custom Methods
 
+    ############################################################################
+
     use Extender;
 
     # Extend an object with custom methods
@@ -651,8 +697,12 @@ sub Unload {
     $object->greet('Alice');               # Output: Hello, Alice!
     $object->custom_method('Hello');       # Assuming some_function prints something
 
+    ############################################################################
+
 =head2 Adding Methods to Raw Reference Variables
 
+    ############################################################################
+
     package HashMethods;
 
     use strict;
@@ -672,6 +722,8 @@ sub Unload {
 
     1;
 
+    ############################################################################
+
     package ArrayMethods;
 
     use strict;
@@ -691,6 +743,8 @@ sub Unload {
 
     1;
 
+    ############################################################################
+
     package ScalarMethods;
 
     use strict;
@@ -720,7 +774,7 @@ sub Unload {
 
     1;
 
-    # MAIN 
+    ############################################################################
 
     package main;
 
@@ -763,15 +817,22 @@ sub Unload {
 
     1;
 
+    ############################################################################
+
 =head2 Adding methods using anonymous subroutines and existing functions
 
+    ############################################################################
+
     package MyClass;
     sub new {
         my $class = shift;
         return bless {}, $class;
     }
 
+    ############################################################################
+
     package main;
+
     use Extender;
 
     my $object = MyClass->new();
@@ -785,8 +846,12 @@ sub Unload {
     $object->greet('Alice'); # Output: Hello, Alice!
     $object->custom_method('Hello'); # Assuming some_function prints something
 
+    ############################################################################
+
 =head2 Using Shared Object for Shared Variable functionality
 
+    ############################################################################
+
     package main;
 
     use strict;
@@ -795,6 +860,8 @@ sub Unload {
     use threads::shared;
     use Extender;
 
+    ############################################################################
+
     # Example methods to manipulate shared data
 
     # Method to set data in a shared hash
@@ -839,6 +906,8 @@ sub Unload {
         return ${$self};
     }
 
+    ############################################################################
+
     # Create shared data structures
     my %shared_hash :shared;
     my @shared_array :shared;
@@ -849,6 +918,8 @@ sub Unload {
     my $shared_array_object = \@shared_array;
     my $shared_scalar_object = \$shared_scalar;
 
+    ############################################################################
+
     # Extend the shared hash object with custom methods
     Extends($shared_hash_object,
         set_hash_data => \&set_hash_data,
@@ -867,6 +938,8 @@ sub Unload {
         get_scalar_data => \&get_scalar_data,
     );
 
+    ############################################################################
+
     # Create threads to manipulate shared objects concurrently
 
     # Thread for shared hash object
@@ -887,6 +960,8 @@ sub Unload {
         print "Scalar thread: value = " . $shared_scalar_object->get_scalar_data() . "\n";
     });
 
+    ############################################################################
+
     # Wait for all threads to finish
     $hash_thread->join();
     $array_thread->join();
@@ -894,8 +969,12 @@ sub Unload {
 
     1;
 
+    ############################################################################
+
 =head2 Updating existing methods on an object class
 
+    ############################################################################
+
     package MyClass;
 
     sub new {
@@ -908,7 +987,10 @@ sub Unload {
         return "Original method";
     }
 
+    ############################################################################
+
     package main;
+
     use Extender;
 
     my $object = MyClass->new();
@@ -923,12 +1005,18 @@ sub Unload {
 
     1;
 
+    ############################################################################
+
 =head2 Creating Extender Class objects from any (even shared) reference typed variable
 
+    ############################################################################
+
     package main;
 
     use Extender;
 
+    ############################################################################
+
     my $object = Extend({},'Extender');
 
     # Define a method with the same name as an existing method
@@ -939,6 +1027,8 @@ sub Unload {
     # Using the method
     print $object->method(), "\n";  # Outputs: method
 
+    ############################################################################
+
     my $array = Extend([],'Extender');
 
     # Define a method with the same name as an existing method
@@ -949,6 +1039,8 @@ sub Unload {
     # Using the method
     print $array->method(), "\n";  # Outputs: method
 
+    ############################################################################
+
     my $scalar = Extend(\"",'Extender');
 
     # Define a method with the same name as an existing method
@@ -959,8 +1051,57 @@ sub Unload {
     # Using the method
     print $scalar->method(), "\n";  # Outputs: method
 
+    ############################################################################
+
+    my $glob = Extend(\*GLOB,'Extender');
+
+    # Define a method with the same name as an existing method
+    $glob->Extends(
+        method => sub { return "method"; },
+    );
+
+    # Using the method
+    print $glob->method(), "\n";  # Outputs: method
+
     1;
 
+    ############################################################################
+
+=head2 Creating INIT and DESTRUCT Hooks
+
+    ############################################################################
+
+    package TestObject;
+
+    sub new {
+        my $self = bless {}, shift;
+        return $self;
+    }
+
+    sub DESTROY {
+        my $self = shift;
+        # Implement destruction logic if needed
+    }
+
+    ############################################################################
+
+    package main;
+
+    use Extender;
+
+    InitHook('TestObject', 'INIT', sub {
+        print "Initializing object\n";
+    });
+
+    InitHook('TestObject', 'DESTRUCT', sub {
+        print "Destructing object\n";
+    });
+
+    my $object = TestObject->new(); # Output: Initializing object
+    undef $object; # Output: Destructing object
+
+    ############################################################################
+
 =cut
 
 ################################################################################
